// This is the main white rabbit header.
// Use this as your application include.
//
// (C) 2003 Sean Rae

#ifndef WR_H
#define WR_H

namespace WR
{
    enum Expression
    {
        IDLE, // nothing special
        HAPPY, // smiling and bouncing around
        SAD, // poked-out lower lip, mopey
        ANGRY, // face red, fast movement, muscles bulging
        CALM, // eyes slitted, slow movement
        DISAPPROVAL, // pursed mouth, hands on hips
        ALARMED, // eyes wide and bright and fast motion
        HIDING, // running offscreen or behind windows
        HEARING, // cupping hand to ear
        THINKING // holding chin and wrinkling brow
    };

    enum Mode
    {
        NONE, // nothing special
        AVOIDCURSOR, // avoids the mouse cursor
        FOLLOW // follows another avatar
    };
    
    class Avatar
    {
        public:
            Avatar();
            ~Avatar();

            // this will open the filename.wr theme 
            // that contains the complete description of
            // the avatar in binary format.  it will also
            // activate the initialization steps that the
            // avatar goes through on the screen, 
            // e.g. walking onto the screen and saying hi
            void open(string filename) throw(invalidFileException);

            // this method will switch avatars to the
            // one specified in the filename
            void switchTo(string filename) throw(invalidFileException);

            // this method will close the currently 
            // opened avatar.  this should only be used
            // on destruction of the WR system
            void close();

            // Send a string to the avatar to speak
            // through a text box or TTS, depending on
            // system settings. after speaking, each
            // model will return to the IDLE expression.
            void speak(string output);

            // Move the avatar to a certain point on
            // the screen.  The z axis value is 
            // currently ignored, but is kept for future
            // compatibility with 3D desktops.
            void moveTo(int x, int y, int z=0) throw(invalidCoordinateException);

            // point at a certain location on the screen.
            // same goes for the z-coordinate here.
            void pointTo(int x, int y, int z=0) throw(invalidCoordinateException);

            // Special modes can be extended as the abilities of
            // WR expand.  Currently implemented is AVOIDCURSOR,
            // which will make the avatar actively "fear" the
            // cursor and thus run away from it.
            void setMode(Mode);

            // see Expression for all possible values of input
            void setExpression(Expression);
    };
}
#endif
